@@ -430,7 +430,7 @@ class SwachhSabText(SwachhText):
 
         if 'exp_contraction' in kwargs and kwargs['exp_contraction']:
             if verbose:
-                print('Expanding conractions...')
+                print('Expanding contractions...')
             self.text = SwachhText.map_contraction(self)
         
         if 'lower_case' in kwargs and kwargs['lower_case']:
